@@ -4,7 +4,9 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.29'; # VERSION
+use URI::Split qw(uri_split);
+
+our $VERSION = '0.30'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -39,6 +41,11 @@ sub check_request {
     return [400, "Invalid action, please only use letters/numbers"]
         unless $action =~ $re_action;
 
+    if (defined $req->{uri}) {
+        ($req->{-uri_scheme}, $req->{-uri_auth}, $req->{-uri_path},
+         $req->{-uri_query}, $req->{-uri_frag}) = uri_split($req->{uri});
+    }
+
     # return success for further processing
     0;
 }
@@ -56,13 +63,23 @@ Perinci::Access::Base - Base class for all Perinci Riap clients
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 DESCRIPTION
 
 This is a thin base class for all Riap clients (C<Perinci::Access::*>). It
-currently only provides check_request() to do some basic sanity checking of the
-Riap request hash C<$req>. It also provides a barebones C<new()>.
+currently only provides check_request() which does the following:
+
+=over
+
+=item * perform some basic sanity checking of the Riap request hash C<$req>
+
+=item * split request keys C<uri>
+
+Split result is put in C<< $req->{-uri_scheme} >>, C<< $req->{-uri_auth} >>, C<<
+$req->{-uri_path} >>, C<< $req->{-uri_query} >>, and C<< $req->{-uri_frag} >>.
+
+=back
 
 =head1 METHODS
 
